% function DP = DP_of_phi(F, lambda, sd, beta, myparam)
% 
% The function DP is the function we need to minimize in order to compute
% the optimal parameter for the spectral filters based on the Discrepancy 
% Principle method, the absolute value of the norm of the residual minus 
% its target value.
%
% -------------------------------------------------------------------------
% Input:
% -------------------------------------------------------------------------
% F         : A function handle so that F(lambda, sd, beta, myparam)
%             returns the n values of the filter evaluated at the
%             singular values sd. 
% lambda    : The parameter of the filter
% sd        : Singular values of the bluring matrix, descending order
% beta      : Right hand side in the singular value space
% myparam   : A structure containing extra information needed
%             to construct the filter, including myparam.DPtarget.
% -------------------------------------------------------------------------
% Output:
% -------------------------------------------------------------------------
% DP         : The function value DP
% -------------------------------------------------------------------------
%
% This is code to accompany:
% Near-Optimal Spectral Filtering and Error Estimation
% for Solving Ill-Posed Problems,
% Viktoria Taroudaki and Dianne P. O'Leary,
% University of Maryland, 2015.


function DP = DP_of_phi(F, lambda, sd, beta, myparam)

filter = feval(F, lambda, sd, beta, myparam);

xhat = ( beta ./ sd ) .* filter;

resid = beta - sd .* xhat;

DP = abs(norm(resid) - myparam.DPtarget); 
 
 
