% function [phi] = phi_TSVD(lambda, sd, beta, myparam)
% 
% This routine computes the Truncated SVD (TSVD) filter for numerical 
% solution of ill-posed problems, including 
% reconstruction of images that have been blurred.
%
% The filter is defined as: 
% 
%    phi(j) = 1 if 0 < j <= lambda,
%           = 0 otherwise.
%           
% -------------------------------------------------------------------------
% Input:
% -------------------------------------------------------------------------
% lambda    : Truncation parameter.
% sd        : Singular values of the blurring matrix in non-increasing 
%             order.
% beta      : Right hand side in the coordinate system of the
%             singular vectors. (not used)
% myparam   : A structure containing extra information: not used.
% -------------------------------------------------------------------------
% Output:
% -------------------------------------------------------------------------
% phi       : The TSVD filter (vector of length nphi).
% -------------------------------------------------------------------------
%
% This is code to accompany:
% Near-Optimal Spectral Filtering and Error Estimation
% for Solving Ill-Posed Problems,
% Viktoria Taroudaki and Dianne P. O'Leary,
% University of Maryland, 2015.

function [phi] = phi_TSVD(lambda, sd, beta, myparam)

phi=zeros(size(sd));
phi(1:lambda) = 1;
